@@ -8,15 +8,15 @@ use Catalyst::Utils;
 use DirHandle;
 use NEXT;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 sub find_files {
     my $c = shift;
-    
+
     my @files    = $c->SUPER::find_files();
     my @my_files = $c->_find_my_files();
 
-    return (@files, @my_files);
+    return ( @files, @my_files );
 }
 
 sub _find_my_files {
@@ -26,26 +26,41 @@ sub _find_my_files {
     return [] if $extension;
 
     my $prefix = Catalyst::Utils::appprefix( ref $c || $c );
-    my $path   = $path_prefix;
-    $path      =~ s{\/$prefix$}{};
+    my $path = $path_prefix;
+    $path =~ s{\/$prefix$}{};
 
     my @extensions = @{ Config::Any->extensions };
     my $suffix     = $c->get_config_local_suffix;
     my @my_files   = ();
-    my $dh = DirHandle->new( $path );
+    my $dh         = DirHandle->new($path);
+
+    my $config_key_name = uc($prefix) . '_CONFIG_MULTI';
+
 
     while ( my $file = $dh->read() ) {
         next unless $file =~ /^$prefix\_(.+)\.\w+$/ && $suffix ne $1;
-        push @my_files,
-             ( map {
-                    (
-                        "${path_prefix}_${1}.$_",
+
+
+        if ( $ENV{ $config_key_name } ) {
+            push @my_files, (
+                map {
+                    (   "${path_prefix}_${1}.$_",)
+                    } @extensions
+            );
+        }
+        else {
+            push @my_files, (
+                map {
+                    (   "${path_prefix}_${1}.$_",
                         "${path_prefix}_${1}_${suffix}.$_"
-                    )
-                   } @extensions
-             ); 
+                        )
+                    } @extensions
+            );
+        }
     }
 
+    push @my_files ,  $ENV{ $config_key_name } if $ENV{ $config_key_name };
+
     return @my_files;
 }
 
@@ -102,9 +117,9 @@ Your directory
 
 =head1 DESCRIPTION
 
-When a project is getting bigger and biggger , it is hard to organaize a config
+When a project is getting bigger and bigger , it is hard to organize a config
 file. So we create this plugin which divide a config file to multiple. Config
-files name must start your project prrefix. such as 'myapp_' .
+files name must start your project prefix. such as 'myapp_' .
 
  __PACKAGE__->config( 'Plugin::ConfigLoader' => { file => __PACKAGE__->path_to('conf')  } );
 
@@ -116,6 +131,12 @@ Do not forget add this code to your MyApp.pm
 
 override from ConfigLoader
 
+=head1 ENV
+
+you can specify local file with this setting.
+
+ $ENV{MYAPP_CONFIG_MULTI} = '/tmp/foo/your_own_local.yaml'
+
 =head1 SEE ALSO
 
 L<Catalyst::Plugin::ConfigLoader>
